<!-- ...................................................................... -->
<!-- PRISM Aggregator Markup language Content Model Module  ............... -->
<!-- file: pam-model.mod

     This file provides the overall content model for the 
     PRISM Aggregator Message format. The content model is a mix of
     elements from the XHTML, Dublin Core, PRISM, PRISM Inline
     Markup, and PAM namespaces. Much of this file is a duplicate
     of the entities defined in the XHTML content model, some of
     which have been tweaked to allow the elements from other namespaces.

     This module is identified by the PUBLIC identifier:
       PUBLIC "-//PRISMstandard.org//PRISM Aggregator Message Model 1.0//EN"

     It also has a default SYSTEM identifier:
         http://prismstandard.org/PAM_1.0/pam-model.mod
 
     ...................................................................... -->

<!-- Define the content model for Misc.extra
 -->
<!ENTITY % Misc.class "| %PAM.media.qname;" >

<!-- Define an entity for the PRISM Inline Markup elements. -->
<!ENTITY % PIM.class
     "| %PIM.event.qname; | %PIM.location.qname; | %PIM.objectTitle.qname;
      | %PIM.organization.qname; | %PIM.person.qname; | %PIM.quote.qname; " >


<!-- ....................  Inline Elements  ......................

    For the most part, this section just repeats declarations from
    XHTML. A few of those declarations will have PAM-specific items
    mixed in.
-->


<!ENTITY % I18n.class "| %bdo.qname;" >
<!ENTITY % Ruby.class "| %ruby.qname;" >

<!ENTITY % InlStruct.class "%br.qname; | %span.qname;" >


<!ENTITY % InlPhras.class
     "| %em.qname; | %strong.qname; | %dfn.qname; | %code.qname; 
      | %samp.qname; | %kbd.qname; | %var.qname; | %cite.qname; 
      | %abbr.qname; | %acronym.qname; | %q.qname; " >

<!ENTITY % InlPres.class
        "| %b.qname; | %big.qname; | %i.qname; | %small.qname;
         | %sub.qname;  | %sup.qname;  | %tt.qname;" >

<!ENTITY % Anchor.class "| %a.qname;" >

<!ENTITY % InlSpecial.class "" >

<!ENTITY % Inline.extra " %PIM.class; " > 

<!-- %Inline.class; includes all inline elements,
     used as a component in mixes
-->
<!ENTITY % Inline.class
     "%InlStruct.class;
      %InlPhras.class;
      %InlPres.class;
      %I18n.class;
      %Anchor.class;
      %InlSpecial.class;
      %Ruby.class;
      %Inline.extra;"
>

<!-- %InlNoAnchor.class; includes all non-anchor inlines,
     used as a component in mixes
-->
<!ENTITY % InlNoAnchor.class
     "%InlStruct.class;
      %InlPhras.class;
      %InlPres.class;
      %InlSpecial.class;"
>

<!-- %InlNoAnchor.mix; includes all non-anchor inlines
-->
<!ENTITY % InlNoAnchor.mix
     "%InlNoAnchor.class;
      %Misc.class;"
>

<!-- %Inline.mix; includes all inline elements, including %Misc.class;
-->
<!ENTITY % Inline.mix
     "%Inline.class;
      %Misc.class;"
>


<!-- .....................  Block Elements  ...................... -->

<!ENTITY % Heading.class 
     "%h1.qname; | %h2.qname; | %h3.qname; 
      | %h4.qname; | %h5.qname; | %h6.qname;" >

<!ENTITY % List.class "%ul.qname; | %ol.qname; | %dl.qname;" >

<!ENTITY % BlkStruct.class "%p.qname; | %div.qname; | %table.qname;" >

<!ENTITY % BlkPhras.class 
     "| %pre.qname; | %blockquote.qname; | %address.qname;" >

<!ENTITY % BlkPres.class "" >

<!ENTITY % Block.extra "" >

<!-- %Block.class; includes all block elements,
     used as an component in mixes
-->
<!ENTITY % Block.class
     "%BlkStruct.class;
      %BlkPhras.class;
      %BlkPres.class;
      %Block.extra;"
>

<!-- %Block.mix; includes all block elements plus %Misc.class;
-->
<!ENTITY % Block.mix
     "%Heading.class;
      | %List.class;
      | %Block.class;
      %Misc.class;"
>

<!-- ................  All Content Elements  .................. -->

<!-- %Flow.mix; includes all text content, block and inline
-->
<!ENTITY % Flow.mix
     "%Heading.class;
      | %List.class;
      | %Block.class;
      | %Inline.class;
      %Misc.class;"
>

<!-- special content model for pre element -->
<!ENTITY % pre.content
    "( #PCDATA
     | %Inline.class; )*"
>


<!-- Define the metadata header structure ................................ -->
<!ENTITY % HeadOpts.mix "" >

<!ENTITY % head.content
   
   "( %DC.identifier.qname; ,
      %PAM.status.qname;? ,
      %PRISM.hasCorrection.qname;? ,
      %DC.title.qname;?  ,
      %DC.creator.qname;*  ,
      %PRISM.publicationName.qname;  ,
      %PRISM.issn.qname;? ,
      %DC.publisher.qname;?  ,
      
      ((%PRISM.coverDate.qname; , %PRISM.coverDisplayDate.qname;?)
       | %PRISM.coverDisplayDate.qname;
      ) ,
 
      %PRISM.volume.qname;? ,
      %PRISM.number.qname;? ,
      %PRISM.issueName.qname;? ,
      %PRISM.edition.qname;? ,
      %PRISM.startingPage.qname;?  ,
      %PRISM.section.qname;?  ,
      %PRISM.subsection1.qname;?  ,
      %PRISM.subsection2.qname;?  ,
       ( %DC.subject.qname; | %PRISM.event.qname; | %PRISM.location.qname;
       | %PRISM.objectTitle.qname; | %PRISM.organization.qname;
       | %PRISM.person.qname; )* ,
      %PRISM.category.qname;* ,
      %PRISM.copyright.qname;?
   )"
>
      

<!-- Allow prism:copyright statements in tables (in the footer) -->
<!ENTITY % tfoot.content  "( %tr.qname; | %PRISM.copyright.qname; )+" >

<!-- end of pam-model.mod -->

