<!-- ...................................................................... -->
<!-- PRISM Aggregation Message  Extension Module .......................... -->
<!-- file: pam.mod

     This file defines the content models for the elements in the
     PAM (PRISM Aggregator Message) namespace.
     The PAM format is a mix of XHTML, Dublin Core, PRISM metadata, and
     PRISM Inlin Markup, plus enough glue elements to bring those together
     and fill in any missing functionality. This module defines the glue
     and missing elements.

     This DTD module is identified by the PUBLIC identifier:

       PUBLIC "-//PRISMstandard.org//ENTITIES PAM 1.0//EN"

     By default, it is accessed with the SYSTEM identifier:
       SYSTEM "http://prismstandard.org/PAM/pam.mod"

     Revisions:
     (none)

     2003-03-17
     Ron Daniel Jr.
     Taxonomy Strategies
     rdaniel@taxonomystrategies.com
     ....................................................................... -->

<!-- ......................................................................  -->

<!-- 1. Declare the xmlns attributes used by PAM dependent on whether
        PAM's prefixing is active.

        If the PAM elements will be namespace-prefixed, PAM should inherit
        %NS.decl.attrib;, which will have all the namespace declarations.
        Otherwise it should declare %NS.decl.attrib; plus define a default
        xmlns attribute on its own element types.
-->
<![%PAM.prefixed;[
<!ENTITY % PAM.xmlns.attrib
     "%NS.decl.attrib;"
>
]]>
<!ENTITY % PAM.xmlns.attrib
     "%NS.decl.attrib;
     xmlns  %URI.datatype;  #FIXED  '%PAM.xmlns;'"
>


<!-- 2. Declare the elements and their attributes.

        In the attribute list for each element, declare the XML Namespace
        declarations that are legal in the document instance by including
        the Namespace Declaration parameter entity (%PAM.xmlns.attrib;)
        in the ATTLIST of each element type.
-->


<!ELEMENT %PAM.message.qname;  ( %PAM.article.qname; )+ >
<!ATTLIST %PAM.message.qname;
      %PAM.xmlns.attrib;
>

<!ELEMENT %PAM.article.qname;  ( %head.qname; , (%body.qname;)? ) >
<!ATTLIST %PAM.article.qname;
      %I18n.attrib;
      %PAM.xmlns.attrib;
>
<!-- Note that the body is optional. This is for the corrections scenario,
     when all that is being sent is a correction block.

     Note that the <pam:article> element allows the xml:lang attribute.
     As in XHTML, that attribute is allowed inside the articles as well.
     However, considerable testing will be needed before a publisher could
     rely on any language indications actually having an effect that is
     visible to an end-user of an aggregation service.  There is no harm
    in providing the markup, but it is highly likely to be ignored.
-->
<!ELEMENT %PAM.status.qname;  ( #PCDATA ) >
<!ATTLIST %PAM.status.qname;
      %PAM.xmlns.attrib;
>

<!ENTITY % media.content "(
      %DC.type.qname;* ,
      %PAM.mediaref.qname;* ,
      %PAM.credit.qname;? ,
      %caption.qname;? ,
      %PRISM.copyright.qname;? ,
      %PAM.textdesc.qname;? ,
      %PAM.extension.qname;?
     )" >

<!ELEMENT %PAM.media.qname; %media.content; >

<!ATTLIST %PAM.media.qname;
      %PAM.xmlns.attrib;
>

<!ELEMENT %PAM.mediaref.qname; EMPTY >
<!ATTLIST %PAM.mediaref.qname;
      %PAM.refid.qname;     CDATA  #REQUIRED
      %PAM.mimetype.qname;  CDATA  #IMPLIED
      %PAM.xmlns.attrib;
>

<!ELEMENT %PAM.credit.qname;    (#PCDATA) >
<!ATTLIST %PAM.credit.qname;
      %PAM.xmlns.attrib;
>

<!ELEMENT %PAM.textdesc.qname;  (#PCDATA) >
<!ATTLIST %PAM.textdesc.qname;
      %PAM.xmlns.attrib;
>

<!ELEMENT %PAM.extension.qname;  ANY  >
<!ATTLIST %PAM.extension.qname;
      %PAM.xmlns.attrib;
>

<!-- end of pam.mod -->
